#!/usr/bin/env python3

import tkinter
import tkinter.messagebox
import tkinter.filedialog
import os
import tkinter.font

class App:
    def __init__(self, master):
        self.master = master
        self.szövegterületet_készít()
        self.menüsort_készít() 
        self.fájl_üreset_állít()
        self.színek = tkinter.StringVar(value='vhsb')
        self.dőlt = tkinter.IntVar(value=0)
        self.félkövér = tkinter.IntVar(value=0)

    def szövegterületet_készít(self):
        self.szövegterület = tkinter.Text(self.master)
        self.szövegterület.pack(expand=True, fill='both')

    def menüsort_készít(self):
        self.menüsor = tkinter.Menu(self.master)
        
        fájl_menü = tkinter.Menu(self.menüsor, tearoff=0)
        fájl_menü.add_command(label='Új', command=self.fájl_üreset_állít)
        fájl_menü.add_command(label='Megnyitás', command=self.fájl_megnyit)
        fájl_menü.add_command(label='Mentés', command=self.fájl_ment)
        fájl_menü.add_separator()
        fájl_menü.add_command(label='Beállítások')
        fájl_menü.add_separator()
        fájl_menü.add_command(label='Kilépés', command=self.master.destroy)
        self.menüsor.add_cascade(label='Fájl', menu=fájl_menü)

        súgó_menü = tkinter.Menu(self.menüsor, tearoff=0)
        súgó_menü.add_command(label='Névjegy', command=self.ablak_névjegy)
        self.menüsor.add_cascade(label='Súgó', menu=súgó_menü)
        
        self.master.config(menu=self.menüsor)

    def ablak_névjegy(self):
        tkinter.messagebox.showinfo('Névjegy', 'Mi írtuk az egészet!')

    def fájl_üreset_állít(self):
        self.fájlnév = None
        self.szövegterület.delete('1.0', 'end')
        self.ablakcímet_állít()

    def fájl_ment(self):
        if not self.fájlnév: # ha még sosem volt mentve a fájl
            fájlnév = tkinter.filedialog.asksaveasfilename(initialfile='szöveg.txt',
                                                           defaultextension='.txt',
                                                           filetypes=[('Szövegfájlok', '*.txt'),
                                                                      ('Minden fájl', '*.*')])
        else:
            fájlnév = self.fájlnév # ha már volt mentve a fájl, akkor tudjuk a nevét is
        if fájlnév != '': # ha megadott fájlnevet, vagy már eredetileg is volt
            with open(fájlnév, 'w') as célfájl: # akkor kiírjuk
                célfájl.write(self.szövegterület.get('1.0', 'end')) # az 1. sor 0. karakterétől a végéig
            self.fájlnév = fájlnév                
            self.ablakcímet_állít()

    def fájl_megnyit(self):
        fájlnév = tkinter.filedialog.askopenfilename(defaultextension='.txt',
                                                     filetypes=[('Szövegfájlok', '*.txt'),
                                                                ('Minden fájl', '*.*')])
        if fájlnév != '': # ha adott meg fájlnevet
            with open(fájlnév) as forrásfájl:
                self.szövegterület.delete('1.0', 'end')
                self.szövegterület.insert('1.0', forrásfájl.read())
            self.fájlnév = fájlnév
            self.ablakcímet_állít()

    def ablakcímet_állít(self):
        if self.fájlnév:
            cím = os.path.basename(self.fájlnév)
        else:
            cím = 'névtelen'
        cím = cím + ' - Sajáttömb'
        self.master.title(cím)


főablak = tkinter.Tk()
app = App(főablak)

főablak.mainloop()

